Crate samplerate

Re-exports

Modules

Functions

  • Perform a simple samplerate conversion of a large chunk of audio. This calls src_simple of libsamplerate which is not suitable for streamed audio. Use the Samplerate struct instead for this.
  • Returns the version of libsamplerate used by this crate as a string.