Re-exports
pub use crate::converter_type::*;pub use crate::error::*;pub use crate::samplerate::*;
Modules
Functions
- Perform a simple samplerate conversion of a large chunk of audio. This calls
src_simpleof libsamplerate which is not suitable for streamed audio. Use theSampleratestruct instead for this. - Returns the version of
libsamplerateused by this crate as a string.